@@ -1,4 +1,4 @@
-/* $Id: parser_interface.c 1284 2008-06-09 12:48:13Z jrjohansen $ */
+/* $Id: parser_interface.c 1386 2009-03-13 04:44:26Z steve-beattie $ */
 
 /*
  *   Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
@@ -95,8 +95,11 @@ static void print_error(int error)
 	case -ENOENT:
 		PERROR(_("Profile doesn't exist\n"));
 		break;
+	case -EACCES:
+		PERROR(_("Permission denied; attempted to load a profile while confined?\n"));
+		break;
 	default:
-		PERROR(_("Unknown error\n"));
+		PERROR(_("Unknown error (%d): %s\n"), -error, strerror(-error));
 		break;
 	}
 }
@@ -887,11 +890,30 @@ exit:
 	return error;
 }
 
+/* bleah the kernel should just loop and do multiple load, but to support
+ * older systems we need to do this
+ */
+#define PROFILE_HEADER_SIZE
+static char header_version[] = "\x04\x08\x00version";
+
+static char *next_profile_buffer(char *buffer, int size)
+{
+	char *b = buffer;
+
+	for (; size - sizeof(header_version); b++, size--) {
+		if (memcmp(b, header_version, sizeof(header_version)) == 0) {
+			return b;
+		}
+	}
+	return NULL;
+}
+
 int sd_load_buffer(int option, char *buffer, int size)
 {
 	int fd;
-	int error = 0, wsize;
+	int error = 0, wsize, bsize;
 	char *filename = NULL;
+	char *b;
 
 	switch (option) {
 	case OPTION_ADD:
@@ -915,12 +937,15 @@ int sd_load_buffer(int option, char *buffer, int size)
 		goto exit;
 	}
 
-	wsize = write(fd, buffer, size);
-	if (wsize < 0) {
-		error = -errno;
-	} else if (wsize < size) {
-		PERROR(_("%s: Unable to write entire profile entry\n"),
-		       progname);
+	for (b = buffer; b ; b = next_profile_buffer(b + sizeof(header_version), bsize)) {
+		bsize = size - (b - buffer);
+		wsize = write(fd, b, bsize);
+		if (wsize < 0) {
+			error = -errno;
+		} else if (wsize < bsize) {
+			PERROR(_("%s: Unable to write entire profile entry\n"),
+			       progname);
+		}
 	}
 	close(fd);
 exit:
