@@ -1,4 +1,4 @@
-/* $Id: parser_merge.c 830 2007-07-27 21:45:45Z steve-beattie $ */
+/* $Id: parser_merge.c 1188 2008-04-10 00:56:31Z jrjohansen $ */
 
 /*
  *   Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
@@ -29,21 +29,50 @@
 #include "parser.h"
 
 
-static inline int count_net_entries(struct codomain *cod)
-{
-	struct cod_net_entry *list;
-	int count = 0;
-	for (list = cod->net_entries; list; list = list->next)
-		count++;
-	return count;
-}
-
 static int file_comp(const void *c1, const void *c2)
 {
 	struct cod_entry **e1, **e2;
 	e1 = (struct cod_entry **)c1;
 	e2 = (struct cod_entry **)c2;
+	int res = 0;
+
 	//PERROR("strcmp %s %s\n", (*e1)->name, (*e2)->name);
+	if ((*e1)->namespace) {
+		if ((*e2)->namespace)
+			res = strcmp((*e1)->namespace, (*e2)->namespace);
+		else
+			return 1;
+	} else if ((*e2)->namespace) {
+		return -1;
+	}
+	if (res)
+		return res;
+
+	if ((*e1)->link_name) {
+		if ((*e2)->link_name)
+			res = strcmp((*e1)->link_name, (*e2)->link_name);
+		else
+			return 1;
+	} else if ((*e2)->link_name) {
+		return -1;
+	}
+	if (res)
+		return res;
+
+	if ((*e1)->link_name)
+		res = (*e2)->subset - (*e1)->subset;
+	if (res)
+		return res;
+
+	if ((*e1)->deny != (*e2)->deny)
+		return (*e1)->deny < (*e2)->deny ? -1 : 1;
+
+	/* rules with ptrace and change_profile can only merge with
+	 * rules with exact same perm */
+	if (((*e1)->mode & (AA_CHANGE_PROFILE | AA_PTRACE_PERMS)) !=
+	    ((*e2)->mode & (AA_CHANGE_PROFILE | AA_PTRACE_PERMS)))
+		return 1;
+
 	return strcmp((*e1)->name, (*e2)->name);
 }
 
@@ -75,26 +104,23 @@ static int process_file_entries(struct codomain *cod)
 	qsort(table, count, sizeof(struct cod_entry *), file_comp);
 	table[count] = NULL;
 
-#define CHECK_CONFLICT_UNSAFE(a, b) \
-	((HAS_EXEC_UNSAFE(a) ^ HAS_EXEC_UNSAFE(b)) && \
-	 ((HAS_EXEC_PROFILE(a) && HAS_EXEC_PROFILE(b)) || \
-	  (HAS_EXEC_UNCONFINED(a) && HAS_EXEC_UNCONFINED(b))))
 
 	/* walk the sorted table merging similar entries */
 	for (cur = table[0], next = table[1], n = 1; next != NULL; n++, next = table[n]) {
 		if (file_comp(&cur, &next) == 0) {
-			int conflict = CHECK_CONFLICT_UNSAFE(cur->mode, next->mode);
-
-			cur->mode |= next->mode;
 			/* check for merged x consistency */
-			if (HAS_MAY_EXEC(cur->mode) &&
-			    (!AA_EXEC_SINGLE_MODIFIER_SET(cur->mode) ||
-			     conflict)) {
+			if (!is_merged_x_consistent(cur->mode, next->mode)) {
 				PERROR(_("profile %s: has merged rule %s with multiple x modifiers\n"),
 				       cod->name, cur->name);
 				return 0;
 			}
+//if (next->audit)
+//fprintf(stderr, "warning: merging rule 0x%x %s\n", next->audit, next->name);
+			cur->mode |= next->mode;
+			cur->audit |= next->audit;
 			free(next->name);
+			if (next->link_name)
+				free(next->link_name);
 			free(next);
 			table[n] = NULL;
 		} else {
@@ -118,17 +144,10 @@ static int process_file_entries(struct codomain *cod)
 	return 1;
 }
 
-static int process_net_entries(struct codomain __unused *cod)
-{
-	return 1;
-}
-
 int codomain_merge_rules(struct codomain *cod)
 {
 	if (!process_file_entries(cod))
 		goto fail;
-	if (!process_net_entries(cod))
-		goto fail;
 
 	/* XXX  return error from this */
 	merge_hat_rules(cod);
