@@ -1,4 +1,4 @@
-/* $Id: parser_misc.c 1287 2008-06-09 22:17:41Z jrjohansen $ */
+/* $Id: parser_misc.c 1402 2009-06-10 21:26:31Z jrjohansen $ */
 
 /*
  *   Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
@@ -27,7 +27,7 @@
 #include <libintl.h>
 #define _(s) gettext(s)
 #include <netinet/in.h>
-#include <sys/socket.h>
+#include <linux/socket.h>
 #include <arpa/inet.h>
 #include <linux/capability.h>
 
@@ -71,6 +71,7 @@ static struct keyword_table keyword_table[] = {
 	{"set",			TOK_SET},
 	{"rlimit",		TOK_RLIMIT},
 	{"alias",		TOK_ALIAS},
+	{"rewrite",		TOK_ALIAS},
 	{"ptrace",		TOK_PTRACE},
 	/* terminate */
 	{NULL, 0}
@@ -467,8 +468,13 @@ static int parse_sub_mode(const char *str_mode, const char *mode_desc)
 reeval:
 		switch (this) {
 		case COD_READ_CHAR:
-			PDEBUG("Parsing mode: found %s READ\n", mode_desc);
-			mode |= AA_MAY_READ;
+			if (read_implies_exec) {
+				PDEBUG("Parsing mode: found %s READ imply X\n", mode_desc);
+				mode |= AA_MAY_READ | AA_EXEC_MMAP;
+			} else {
+				PDEBUG("Parsing mode: found %s READ\n", mode_desc);
+				mode |= AA_MAY_READ;
+			}
 			break;
 
 		case COD_WRITE_CHAR:
@@ -724,7 +730,6 @@ void debug_cod_entries(struct cod_entry *list)
 		debug_base_perm_mask(SHIFT_TO_BASE(item->mode, AA_OTHER_SHIFT));
 		if (item->name)
 			printf("\tName:\t(%s)\n", item->name);
-
 		else
 			printf("\tName:\tNULL\n");
 
@@ -737,6 +742,24 @@ void debug_cod_entries(struct cod_entry *list)
 	}
 }
 
+void debug_flags(struct codomain *cod)
+{
+	printf("Profile Mode:\t");
+
+	if (cod->flags.complain)
+		printf("Complain");
+	else
+		printf("Enforce");
+
+	if (cod->flags.audit)
+		printf(", Audit");
+
+	if (cod->flags.hat)
+		printf(", Hat");
+
+	printf("\n");
+}
+
 static const char *capnames[] = {
 	"chown",
 	"dac_override",
@@ -785,23 +808,18 @@ void debug_cod_list(struct codomain *cod)
 {
 	unsigned int i;
 	if (cod->namespace)
-		printf("Namespcae:\t\t%s\n", cod->namespace);
+		printf("Namespace:\t\t%s\n", cod->namespace);
 
 	if (cod->name)
 		printf("Name:\t\t%s\n", cod->name);
 	else
 		printf("Name:\t\tNULL\n");
 
-	if (cod->sub_name)
-		printf("Subname:\t%s\n", cod->sub_name);
-	else
-		printf("Subname:\tNULL\n");
-
-	if (cod->default_deny)
-		printf("Type:\t\tDefault Deny\t\n");
-	else
-		printf("Type:\t\tDefault Allow\t\n");
+	if (cod->local)
+		printf("Local To:\t%s\n", cod->parent->name);
 
+	debug_flags(cod);
+	
 	printf("Capabilities:\t");
 	for (i = 0; i < (sizeof(capnames)/sizeof(char *)); i++) {
 		if (((1 << i) & cod->capabilities) != 0) {
