@@ -1,5 +1,5 @@
 #! /bin/bash
-# $Id: exec.sh 430 2007-03-08 21:23:17Z steve-beattie $
+# $Id: exec.sh 1153 2008-03-27 02:16:40Z jrjohansen $
 
 #	Copyright (C) 2002-2005 Novell/SUSE
 #
@@ -68,5 +68,5 @@ runchecktest "EXEC unconfined -> confined" pass $file
 
 # UNCONFINED -> CONFINED no access to self binary
 
-genprofile -N image=$file  "/lib/ld*.so*:rix" "/lib/lib*.so*:rm"
+genprofile -N image=$file  "/lib{64,}/ld*.so*:rix" "/lib{64,}/lib*.so*:rm"
 runchecktest "EXEC unconfined -> confined/no access to self" pass $file
