@@ -1,4 +1,4 @@
-/* $Id: readdir.c 264 2006-12-04 06:43:42Z steve-beattie $ */
+/* $Id: readdir.c 1303 2008-10-08 20:43:28Z steve-beattie $ */
 
 /*
  *	Copyright (C) 2002-2006 Novell/SUSE
@@ -14,7 +14,7 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <linux/types.h>
-#include <linux/dirent.h>
+#include <dirent.h>
 #include <linux/unistd.h>
 #include <string.h>
 #include <sys/syscall.h>
